@@ -113,8 +113,10 @@ var (
 	WarnDeprecationCheck      = createConfigSetting("warn-check-deprecation", SetBool, nil, nil, true, true)
 	SkipCheckKVMDriver        = createConfigSetting("skip-check-kvm-driver", SetBool, nil, nil, true, nil)
 	WarnCheckKVMDriver        = createConfigSetting("warn-check-kvm-driver", SetBool, nil, nil, true, false)
-	SkipCheckXHyveDriver      = createConfigSetting("skip-check-xhyve-driver", SetBool, nil, nil, true, nil)
-	WarnCheckXHyveDriver      = createConfigSetting("warn-check-xhyve-driver", SetBool, nil, nil, true, false)
+	SkipCheckHyperkit         = createConfigSetting("skip-check-hyperkit", SetBool, nil, nil, true, nil)
+	WarnCheckHyperkit         = createConfigSetting("warn-check-hyperkit", SetBool, nil, nil, true, false)
+	SkipCheckHyperkitDriver   = createConfigSetting("skip-check-hyperkit-driver", SetBool, nil, nil, true, nil)
+	WarnCheckHyperkitDriver   = createConfigSetting("warn-check-hyperkit-driver", SetBool, nil, nil, true, false)
 	SkipCheckHyperVDriver     = createConfigSetting("skip-check-hyperv-driver", SetBool, nil, nil, true, nil)
 	WarnCheckHyperVDriver     = createConfigSetting("warn-check-hyperv-driver", SetBool, nil, nil, true, false)
 	SkipCheckIsoUrl           = createConfigSetting("skip-check-iso-url", SetBool, nil, nil, true, nil)
